<?php

if (!defined('BASEPATH')) {
    exit('No direct script access allowed');
}

/**
 * Install controller ciext_help_install
 *
 * @author Roman Ratsun
 */
class ciext_help_install extends \Ciext\Controller\AbstractInstallController
{

    public function __construct()
    {
        parent::__construct();

        // Set acl module name
        $this->module_config['module_acl_name'] = 'ciext_help';

        // Set title
        $this->module_config['module_title'] = $this->lang->line('Ciext help');

        // Set module image
        $this->module_config['module_image'] = '';

        // Set actions
        $this->module_config['module_actions'] = array(
            // 'acl_action' => 'description'
            'view_ciext_help'       => $this->lang->line('View module documentation'),
            'view_ciext_user_guide' => $this->lang->line('View ciext user guide'),
            'view_programmer_docs'  => $this->lang->line('View documents for programmer'),
        );

        // Set menu items
        $this->module_config['module_menu_items'] = array(
            array('documentation', $this->lang->line('View module documentation'), '', 'view_ciext_help'),
            array('index', $this->lang->line('View ciext user guide'), '', 'view_ciext_user_guide'),
        );
    }

}
