<?php

return[
    'developer_docs' => [
        'pages' => [
            'ciext_user_guide' => [
                'label'        => 'Написание документации',
                'file'         => __DIR__ . '/../docs/create.md',
                'position'     => 1000,
            ],
        ]
    ]
];
